require_dependency 'packages/package_methods'

class External::SubmissionsController < UnauthenticatedController
  include PackageMethods

  layout 'external_user'
  helper :send
  helper :deliveries

  before_filter :check_permissions
  before_filter :find_metadata

  def current_user
    User.find_by_name invitation.invitee.name unless invitation.nil?
  end

  def new
    @submission_recipient = invitation.inviter.display_name
    @form_title = t('app.controllers.external.submissions_controller.send_to_recipient', name: (@submission_recipient))
    render 'send/new'
  end

  def create
    submit
  end

  def find
    package = EPackage.find_by_e_package_uuid(params[:package])
    delivery = Delivery.find_by_e_package_id(package.id)
    statusCode = delivery.dbox_extusr_sender_pkg_passcode
    render text: statusCode
  end

private

  def check_permissions
    redirect_to expired_or_invalid_path and return unless params[:passcode].present?
    redirect_to expired_or_invalid_path and return if invitation.nil?
    redirect_to expired_or_invalid_path and return if invitation.expired?
    redirect_to expired_or_invalid_path and return if current_user.nil?
    if invitation.inviter.kind_of? User
      redirect_to expired_or_invalid_path and return if invitation.inviter.inactive?
    else
      # should not be using this controller for dropbox invitations
      redirect_to new_external_dropbox_submission_path(passcode: params[:passcode]) and return
    end

    if invitation.public?
      redirect_to expired_or_invalid_path and return unless invitation.inviter.show_public_url?
    end
    redirect_to expired_or_invalid_path if current_user.home_server != HomeServer.this_server
  end

  def invitation
    Invitation.find_by_passcode params[:passcode].to_s
  end

  def find_metadata
    if invitation.inviter.is_a?(EWorkgroup) && invitation.inviter.dropbox?
      profile = MetadataProfile.find_by_id invitation.inviter.dbox_mdata_profile_id
      @metadata = profile ? profile.all_fields_array : []
      @metadata_title_and_note_reqs = profile ? metadata_profile.title_and_note_requirements : {}
    else
      @metadata = active_metadata_fields
      @metadata_title_and_note_reqs = active_metadata_profile.present? ? active_metadata_profile.title_and_note_requirements : {}
    end
  end
end
