require_dependency 'packages/package_methods'

# REMARK - this controller should be named External::UserDeliveryController
class ExternalDeliveryController < UnauthenticatedController
  include PackageMethods

  layout 'external_user'
  helper :packages

  helper_method :downloadable_object

  before_filter :find_user_delivery, :enforce_self_registration

  def scope
    'external'
  end

  def current_user
    @current_user ||= ExternalUser.find_by_id(@user_delivery.recipient_id) rescue nil
  end

  def find_user_delivery

    # remove any special characters including quotes. Rails default sanitize method does not remove quotes.
    params[:id].gsub!(/[^0-9A-Za-z]/, '')
    params[:passcode].gsub!(/[^0-9A-Za-z]/, '')
    passcode = params[:passcode].to_s

    @user_delivery ||= begin
     UserDelivery.first(
      :conditions => {
        id: sanitize(params[:id]),
        send_to_email_passcode: sanitize(passcode)
      }
    )
    end
  end

  def enforce_self_registration
    if current_user && EConfiguration.first.require_external_users_to_register
      redirect_to login_url(registration_email: current_user.email, :local => true)
    end
  end

  def show
    if @user_delivery.nil? || @user_delivery.recipient.nil?
      # bad passcode or recipient no longer exists
      redirect_to page_not_found_url and return
    elsif @user_delivery.recipient.is_a?(AuthorizableUser)
      # external user has been upgraded, require login

      if @user_delivery.recipient.saml?
        redirect_to received_url(@user_delivery, saml_provider: @user_delivery.recipient.saml_configuration_id) and return
      else
        redirect_to received_url(@user_delivery, local: true) and return
      end
    end

    begin
      _package = EPackage.find(@user_delivery.e_package_id)
      _delivery = Delivery.find(@user_delivery.delivery_id)
    rescue
      @error_message = 'Package record not found.'
      render :action => 'error'
      return
    end

    _econfig = EConfiguration.first

    if _econfig.email_passcode_expires?
      if _delivery.release_policy == Delivery::RELEASE_POLICY_ON_DATE
        _age_seconds = Time.now - _delivery.release_date
      else
        _age_seconds = Time.now - (@user_delivery.forward? ? _delivery.created_at : _package.e_package_upload_completion_time)
      end
      if _age_seconds > (_econfig.email_passcode_days_valid * 86400)
        @error_message = "Your access permission for this package expired at #{(_package.e_package_upload_completion_time + 86400 * _econfig.email_passcode_days_valid).strftime('%I:%M %p, %a %b %d')}. Packages must be retrieved within #{_econfig.email_passcode_days_valid} day(s)."
        render :action => 'error'
        return
      end
    end

    if _econfig.email_passcode_expire_after_download
      _successful_full_downloads = _package.e_sessions.count(:conditions => ['initiator_user_id = ? AND status = ? AND partial_package = ?',
                                                                             current_user.id,
                                                                             'Completed',
                                                                             false])
      if _successful_full_downloads > 0
        @error_message = "External users are only allowed to download full package once. You (or someone else using the link emailed to you) have already downloaded this package."
        render :action => 'error'
        return
      end
    end

    # mark package as read
    _package.mark_as_viewed_for_user(current_user.id)

    super # call PackageMethods mixin method
  end

  def error
  end

  def downloadable_object
    @downloadable_object ||= UserDelivery.find(params[:id]).downloadable_object
  end
end
