class PackageRelayController < UnauthenticatedController

  skip_before_filter :set_expiry_time

  def relay_package
    begin
      ip = request.remote_ip
      host = request.remote_host
      relay = MultiServer::RelayDescriptor.new(params, ip, host)
      response = MultiServer::RelayReceiver.receive_package_relay(relay)
      render text: response, content_type: "text/plain", status: 200
    rescue RelayAuthenticationFailed
      msg = $!.to_s
      logger.info("Unauthorized package-relay attempt from " +
                     "#{request.remote_ip.inspect}: " +
                     msg)
      render text: msg, content_type: "text/plain", status: 401
    rescue Exception
      bt = $!.backtrace.join("\n")
      msg = $!.to_s
      logger.info("Package-relay error: #{msg}\n#{bt}")
      render text: msg, content_type: "text/plain", status: 500
    end
  end

  def relay_access
    begin
      ip = request.remote_ip
      response = MultiServer::RelayReceiver.receive_access_relay(params, ip)
      render text: response, content_type: "text/plain", status: 200
    rescue RelayAuthenticationFailed
      msg = $!.to_s
      logger.info("Unauthorized access-relay attempt from " +
                     "#{request.remote_ip.inspect}: " +
                     msg)
      render text: msg, content_type: "text/plain", status: 401
    rescue Exception
      bt = $!.backtrace.join("\n")
      msg = $!.to_s
      logger.info("Access-relay error: #{msg}\n#{bt}")
      render text: msg, content_type: "text/plain", status: 500
    end
  end

  def ping
    head status: 200 and return
  end
end
